pub struct EdgeCoupledInternalAsymInput {
pub width: f64,
pub spacing: f64,
pub height1: f64,
pub height2: f64,
pub thickness: f64,
pub er: f64,
}Expand description
Inputs for edge-coupled internal asymmetric (offset) differential pair.
Fields
width: f64Conductor width (mils).
spacing: f64Gap between traces (mils).
height1: f64Dielectric height from trace to top ground plane (mils).
height2: f64Dielectric height from trace to bottom ground plane (mils).
thickness: f64Conductor thickness (mils).
er: f64Substrate relative permittivity.