pub fn spacing(input: &SpacingInput) -> Result<SpacingResult, CalcError>Expand description
Look up the IPC-2221C minimum conductor spacing for the given voltage and device type.
Errors
Returns CalcError::OutOfRange if voltage is negative.
pub fn spacing(input: &SpacingInput) -> Result<SpacingResult, CalcError>Look up the IPC-2221C minimum conductor spacing for the given voltage and device type.
Returns CalcError::OutOfRange if voltage is negative.